@@ -1,10 +1,10 @@
 """
 PyGMT is a library for processing geospatial and geophysical data and making
-publication-quality maps and figures. It provides a Pythonic interface for the
-Generic Mapping Tools (GMT), a command-line program widely used across the
-Earth, Ocean, and Planetary sciences and beyond. Besides making GMT more
-accessible to new users, PyGMT aims to provide integration with the PyData
-ecosystem as well as support for rich display in Jupyter notebooks.
+publication-quality maps and figures. It provides a Pythonic interface for the Generic
+Mapping Tools (GMT), a command-line program widely used across the Earth, Ocean, and
+Planetary sciences and beyond. Besides making GMT more accessible to new users, PyGMT
+aims to provide integration with the PyData ecosystem as well as support for rich
+display in Jupyter notebooks.
 
 Main Features
 -------------
@@ -21,13 +21,9 @@ import atexit as _atexit
 import sys
 from importlib.metadata import version
 
-from pygmt import clib
-
 # Get semantic version through setuptools-scm
 __version__ = f'v{version("pygmt")}'  # e.g. v0.1.2.dev3+g0ab3cd78
 __commit__ = __version__.split("+g")[-1] if "+g" in __version__ else ""  # 0ab3cd78
-with clib.Session() as lib:
-    __gmt_version__ = lib.info["version"]
 
 # Import modules to make the high-level GMT Python API
 from pygmt import datasets
@@ -87,19 +83,17 @@ def print_clib_info(file=sys.stdout):
     Includes the GMT version, default values for parameters, the path to the
     ``libgmt`` shared library, and GMT directories.
     """
-    from pygmt.clib import Session  # pylint: disable=import-outside-toplevel
+    from pygmt.clib import Session
 
-    lines = ["GMT library information:"]
+    print("GMT library information:", file=file)
     with Session() as ses:
-        for key in sorted(ses.info):
-            lines.append(f"  {key}: {ses.info[key]}")
+        lines = [f"  {key}: {ses.info[key]}" for key in sorted(ses.info)]
     print("\n".join(lines), file=file)
 
 
 def show_versions(file=sys.stdout):
     """
-    Print various dependency versions which are useful when submitting bug
-    reports.
+    Print various dependency versions which are useful when submitting bug reports.
 
     This includes information about:
 
@@ -108,11 +102,14 @@ def show_versions(file=sys.stdout):
     - Core dependency versions (NumPy, Pandas, Xarray, etc)
     - GMT library information
     """
-    # pylint: disable=import-outside-toplevel
+
     import importlib
     import platform
+    import shutil
     import subprocess
 
+    from packaging.requirements import Requirement
+
     def _get_module_version(modname):
         """
         Get version information of a Python module.
@@ -143,12 +140,10 @@ def show_versions(file=sys.stdout):
             return None
 
         for gs_cmd in cmds:
-            try:
+            if (gsfullpath := shutil.which(gs_cmd)) is not None:
                 return subprocess.check_output(
-                    [gs_cmd, "--version"], universal_newlines=True
+                    [gsfullpath, "--version"], universal_newlines=True
                 ).strip()
-            except FileNotFoundError:
-                continue
         return None
 
     sys_info = {
@@ -157,17 +152,7 @@ def show_versions(file=sys.stdout):
         "machine": platform.platform(),
     }
 
-    deps = [
-        "numpy",
-        "pandas",
-        "xarray",
-        "netCDF4",
-        "packaging",
-        "contextily",
-        "geopandas",
-        "IPython",
-        "rioxarray",
-    ]
+    deps = [Requirement(v).name for v in importlib.metadata.requires("pygmt")]
 
     print("PyGMT information:", file=file)
     print(f"  version: {__version__}", file=file)
