@@ -1,14 +1,14 @@
 """
-Defines the Session class to create and destroy a GMT API session and provides
-access to the API functions.
+Defines the Session class to create and destroy a GMT API session and provides access to
+the API functions.
 
 Uses ctypes to wrap most of the core functions from the C API.
 """
+import contextlib
 import ctypes as ctp
 import pathlib
 import sys
 import warnings
-from contextlib import contextmanager, nullcontext
 
 import numpy as np
 import pandas as pd
@@ -85,8 +85,12 @@ DTYPES = {
     np.float64: "GMT_DOUBLE",
     np.str_: "GMT_TEXT",
     np.datetime64: "GMT_DATETIME",
+    np.timedelta64: "GMT_LONG",
 }
 
+# Load the GMT library outside the Session class to avoid repeated loading.
+_libgmt = load_libgmt()
+
 
 class Session:
     """
@@ -140,7 +144,6 @@ class Session:
     ...             ses.call_module("grdinfo", f"{fin} -C ->{fout.name}")
     ...             # Read the contents of the temp file before it's deleted.
     ...             print(fout.read().strip())
-    ...
     -55 -47 -24 -10 190 981 1 1 8 14 1 1
     """
 
@@ -175,7 +178,7 @@ class Session:
         Dictionary with the GMT version and default paths and parameters.
         """
         if not hasattr(self, "_info"):
-            self._info = {  # pylint: disable=attribute-defined-outside-init
+            self._info = {
                 "version": self.get_default("API_VERSION"),
                 "padding": self.get_default("API_PAD"),
                 # API_BINDIR points to the directory of the Python interpreter
@@ -190,12 +193,10 @@ class Session:
             }
             # For GMT<6.4.0, API_IMAGE_LAYOUT is not defined if GMT is not
             # compiled with GDAL. Since GMT 6.4.0, GDAL is a required GMT
-            # dependency. The try-except block can be refactored after we bump
+            # dependency. The code block can be refactored after we bump
             # the minimum required GMT version to 6.4.0.
-            try:
+            with contextlib.suppress(GMTCLibError):
                 self._info["image layout"] = self.get_default("API_IMAGE_LAYOUT")
-            except GMTCLibError:
-                pass
             # API_BIN_VERSION is new in GMT 6.4.0.
             if Version(self._info["version"]) >= Version("6.4.0"):
                 self._info["binary version"] = self.get_default("API_BIN_VERSION")
@@ -307,13 +308,11 @@ class Session:
         ...     func = lib.get_libgmt_func(
         ...         "GMT_Destroy_Session", argtypes=[c_void_p], restype=c_int
         ...     )
-        ...
         >>> type(func)
         <class 'ctypes.CDLL.__init__.<locals>._FuncPtr'>
         """
         if not hasattr(self, "_libgmt"):
-            # pylint: disable=attribute-defined-outside-init
-            self._libgmt = load_libgmt()
+            self._libgmt = _libgmt
         function = getattr(self._libgmt, name)
         if argtypes is not None:
             function.argtypes = argtypes
@@ -349,7 +348,7 @@ class Session:
         """
         try:
             # Won't raise an exception if there is a currently open session
-            self.session_pointer  # pylint: disable=pointless-statement
+            _ = self.session_pointer
             # In this case, fail to create a new session until the old one is
             # destroyed
             raise GMTCLibError(
@@ -369,27 +368,26 @@ class Session:
 
         # Capture the output printed by GMT into this list. Will use it later
         # to generate error messages for the exceptions raised by API calls.
-        self._error_log = []  # pylint: disable=attribute-defined-outside-init
+        self._error_log = []
 
         @ctp.CFUNCTYPE(ctp.c_int, ctp.c_void_p, ctp.c_char_p)
-        def print_func(file_pointer, message):  # pylint: disable=unused-argument
+        def print_func(file_pointer, message):  # noqa: ARG001
             """
-            Callback function that the GMT C API will use to print log and
-            error messages.
+            Callback function that the GMT C API will use to print log and error
+            messages.
 
-            We'll capture the messages and print them to stderr so that they
-            will show up on the Jupyter notebook.
+            We'll capture the messages and print them to stderr so that they will show
+            up on the Jupyter notebook.
             """
             message = message.decode().strip()
             self._error_log.append(message)
             # flush to make sure the messages are printed even if we have a
             # crash.
-            print(message, file=sys.stderr, flush=True)
+            print(message, file=sys.stderr, flush=True)  # noqa: T201
             return 0
 
         # Need to store a copy of the function because ctypes doesn't and it
         # will be garbage collected otherwise
-        # pylint: disable=attribute-defined-outside-init
         self._print_callback = print_func
 
         padding = self["GMT_PAD_DEFAULT"]
@@ -503,8 +501,8 @@ class Session:
 
     def get_common(self, option):
         """
-        Inquire if a GMT common option has been set and return its current
-        value if possible.
+        Inquire if a GMT common option has been set and return its current value if
+        possible.
 
         Parameters
         ----------
@@ -550,13 +548,11 @@ class Session:
         ...     lib.call_module("plot", "-T -Xw+1i -Yh-1i")
         ...     xshift = lib.get_common("X")  # xshift/yshift are in inches
         ...     yshift = lib.get_common("Y")
-        ...
         >>> print(region, projection, timestamp, verbose, xshift, yshift)
         [ 0. 10. 10. 15.] True False 3 6.0 1.5
         >>> with Session() as lib:
         ...     lib.call_module("basemap", "-R0/10/10/15 -JX5i/2.5i -Baf")
         ...     lib.get_common("A")
-        ...
         Traceback (most recent call last):
         ...
         pygmt.exceptions.GMTInvalidInput: Unknown GMT common option flag 'A'.
@@ -728,16 +724,13 @@ class Session:
         """
         Parse and return an appropriate value for pad if none is given.
 
-        Pad is a bit tricky because, for matrix types, pad control the matrix
-        ordering (row or column major). Using the default pad will set it to
-        column major and mess things up with the numpy arrays.
+        Pad is a bit tricky because, for matrix types, pad control the matrix ordering
+        (row or column major). Using the default pad will set it to column major and
+        mess things up with the numpy arrays.
         """
         pad = kwargs.get("pad", None)
         if pad is None:
-            if "MATRIX" in family:
-                pad = 0
-            else:
-                pad = self["GMT_PAD_DEFAULT"]
+            pad = 0 if "MATRIX" in family else self["GMT_PAD_DEFAULT"]
         return pad
 
     def _parse_constant(self, constant, valid, valid_modifiers=None):
@@ -775,12 +768,11 @@ class Session:
             )
         if nmodifiers > 0 and valid_modifiers is None:
             raise GMTInvalidInput(
-                "Constant modifiers not allowed since valid values were not "
-                + f"given: '{constant}'"
+                "Constant modifiers are not allowed since valid values were not given: '{constant}'"
             )
         if name not in valid:
             raise GMTInvalidInput(
-                f"Invalid constant argument '{name}'. Must be one of {str(valid)}."
+                f"Invalid constant argument '{name}'. Must be one of {valid}."
             )
         if (
             nmodifiers > 0
@@ -788,15 +780,15 @@ class Session:
             and parts[1] not in valid_modifiers
         ):
             raise GMTInvalidInput(
-                f"Invalid constant modifier '{parts[1]}'. Must be one of {str(valid_modifiers)}."
+                f"Invalid constant modifier '{parts[1]}'. Must be one of {valid_modifiers}."
             )
         integer_value = sum(self[part] for part in parts)
         return integer_value
 
     def _check_dtype_and_dim(self, array, ndim):
         """
-        Check that a numpy array has the given number of dimensions and is a
-        valid data type.
+        Check that a numpy array has the given number of dimensions and is a valid data
+        type.
 
         Parameters
         ----------
@@ -824,13 +816,11 @@ class Session:
         >>> with Session() as ses:
         ...     gmttype = ses._check_dtype_and_dim(data, ndim=1)
         ...     gmttype == ses["GMT_DOUBLE"]
-        ...
         True
         >>> data = np.ones((5, 2), dtype="float32")
         >>> with Session() as ses:
         ...     gmttype = ses._check_dtype_and_dim(data, ndim=2)
         ...     gmttype == ses["GMT_FLOAT"]
-        ...
         True
         """
         # Check that the array has the given number of dimensions
@@ -842,8 +832,11 @@ class Session:
         # Check that the array has a valid/known data type
         if array.dtype.type not in DTYPES:
             try:
-                # Try to convert any unknown numpy data types to np.datetime64
-                array = array_to_datetime(array)
+                if array.dtype.type is np.object_:
+                    # Try to convert unknown object type to np.datetime64
+                    array = array_to_datetime(array)
+                else:
+                    raise ValueError
             except ValueError as e:
                 raise GMTInvalidInput(
                     f"Unsupported numpy data type '{array.dtype.type}'."
@@ -908,10 +901,8 @@ class Session:
         )
         if status != 0:
             raise GMTCLibError(
-                (
-                    f"Failed to put vector of type {vector.dtype} "
-                    f"in column {column} of dataset."
-                )
+                f"Failed to put vector of type {vector.dtype} "
+                f"in column {column} of dataset."
             )
 
     def put_strings(self, dataset, family, strings):
@@ -1093,8 +1084,8 @@ class Session:
         if status != 0:
             raise GMTCLibError(f"Failed to write dataset to '{output}'")
 
-    @contextmanager
-    def open_virtual_file(self, family, geometry, direction, data):
+    @contextlib.contextmanager
+    def open_virtualfile(self, family, geometry, direction, data):
         """
         Open a GMT virtual file to pass data to and from a module.
 
@@ -1151,13 +1142,12 @@ class Session:
         ...     lib.put_vector(dataset, column=1, vector=y)
         ...     # Add the dataset to a virtual file
         ...     vfargs = (family, geometry, "GMT_IN|GMT_IS_REFERENCE", dataset)
-        ...     with lib.open_virtual_file(*vfargs) as vfile:
+        ...     with lib.open_virtualfile(*vfargs) as vfile:
         ...         # Send the output to a temp file so that we can read it
         ...         with GMTTempFile() as ofile:
         ...             args = f"{vfile} ->{ofile.name}"
         ...             lib.call_module("info", args)
         ...             print(ofile.read().strip())
-        ...
         <vector memory>: N = 5 <0/4> <5/9>
         """
         c_open_virtualfile = self.get_libgmt_func(
@@ -1200,7 +1190,24 @@ class Session:
             if status != 0:
                 raise GMTCLibError(f"Failed to close virtual file '{vfname}'.")
 
-    @contextmanager
+    def open_virtual_file(self, family, geometry, direction, data):
+        """
+        Open a GMT virtual file to pass data to and from a module.
+
+        .. deprecated: 0.11.0
+
+           Will be removed in v0.15.0. Use :meth:`pygmt.clib.Session.open_virtualfile`
+           instead.
+        """
+        msg = (
+            "API function `Session.open_virtual_file()' has been deprecated "
+            "since v0.11.0 and will be removed in v0.15.0. "
+            "Use `Session.open_virtualfile()' instead."
+        )
+        warnings.warn(msg, category=FutureWarning, stacklevel=2)
+        return self.open_virtualfile(family, geometry, direction, data)
+
+    @contextlib.contextmanager
     def virtualfile_from_vectors(self, *vectors):
         """
         Store 1-D arrays as columns of a table inside a virtual file.
@@ -1215,7 +1222,7 @@ class Session:
         Use this instead of creating the data container and virtual file by
         hand with :meth:`pygmt.clib.Session.create_data`,
         :meth:`pygmt.clib.Session.put_vector`, and
-        :meth:`pygmt.clib.Session.open_virtual_file`.
+        :meth:`pygmt.clib.Session.open_virtualfile`.
 
         If the arrays are C contiguous blocks of memory, they will be passed
         without copying to GMT. If they are not (e.g., they are columns of a
@@ -1248,7 +1255,6 @@ class Session:
         ...         with GMTTempFile() as fout:
         ...             ses.call_module("info", f"{fin} ->{fout.name}")
         ...             print(fout.read().strip())
-        ...
         <vector memory>: N = 3 <1/3> <4/6> <7/9>
         """
         # Conversion to a C-contiguous array needs to be done here and not in
@@ -1291,20 +1297,18 @@ class Session:
             if len(string_arrays) == 1:
                 strings = string_arrays[0]
             elif len(string_arrays) > 1:
-                strings = np.apply_along_axis(
-                    func1d=" ".join, axis=0, arr=string_arrays
-                )
+                strings = np.array([" ".join(vals) for vals in zip(*string_arrays)])
             strings = np.asanyarray(a=strings, dtype=str)
             self.put_strings(
                 dataset, family="GMT_IS_VECTOR|GMT_IS_DUPLICATE", strings=strings
             )
 
-        with self.open_virtual_file(
+        with self.open_virtualfile(
             family, geometry, "GMT_IN|GMT_IS_REFERENCE", dataset
         ) as vfile:
             yield vfile
 
-    @contextmanager
+    @contextlib.contextmanager
     def virtualfile_from_matrix(self, matrix):
         """
         Store a 2-D array as a table inside a virtual file.
@@ -1326,7 +1330,7 @@ class Session:
         Use this instead of creating the data container and virtual file by
         hand with :meth:`pygmt.clib.Session.create_data`,
         :meth:`pygmt.clib.Session.put_matrix`, and
-        :meth:`pygmt.clib.Session.open_virtual_file`
+        :meth:`pygmt.clib.Session.open_virtualfile`
 
         The matrix must be C contiguous in memory. If it is not (e.g., it is a
         slice of a larger array), the array will be copied to make sure it is.
@@ -1359,7 +1363,6 @@ class Session:
         ...         with GMTTempFile() as fout:
         ...             ses.call_module("info", f"{fin} ->{fout.name}")
         ...             print(fout.read().strip())
-        ...
         <matrix memory>: N = 4 <0/9> <1/10> <2/11>
         """
         # Conversion to a C-contiguous array needs to be done here and not in
@@ -1380,12 +1383,12 @@ class Session:
 
         self.put_matrix(dataset, matrix)
 
-        with self.open_virtual_file(
+        with self.open_virtualfile(
             family, geometry, "GMT_IN|GMT_IS_REFERENCE", dataset
         ) as vfile:
             yield vfile
 
-    @contextmanager
+    @contextlib.contextmanager
     def virtualfile_from_grid(self, grid):
         """
         Store a grid in a virtual file.
@@ -1403,7 +1406,7 @@ class Session:
         Use this instead of creating a data container and virtual file by hand
         with :meth:`pygmt.clib.Session.create_data`,
         :meth:`pygmt.clib.Session.put_matrix`, and
-        :meth:`pygmt.clib.Session.open_virtual_file`
+        :meth:`pygmt.clib.Session.open_virtualfile`.
 
         The grid data matrix must be C contiguous in memory. If it is not
         (e.g., it is a slice of a larger array), the array will be copied to
@@ -1441,7 +1444,6 @@ class Session:
         ...             args = f"{fin} -L0 -Cn ->{fout.name}"
         ...             ses.call_module("grdinfo", args)
         ...             print(fout.read().strip())
-        ...
         -55 -47 -24 -10 190 981 1 1 8 14 1 1
         >>> # The output is: w e s n z0 z1 dx dy n_columns n_rows reg gtype
         """
@@ -1468,11 +1470,11 @@ class Session:
         )
         self.put_matrix(gmt_grid, matrix)
         args = (family, geometry, "GMT_IN|GMT_IS_REFERENCE", gmt_grid)
-        with self.open_virtual_file(*args) as vfile:
+        with self.open_virtualfile(*args) as vfile:
             yield vfile
 
     @fmt_docstring
-    def virtualfile_from_data(
+    def virtualfile_from_data(  # noqa: PLR0912
         self,
         check_kind=None,
         data=None,
@@ -1529,14 +1531,11 @@ class Session:
         ...     ),
         ... )
         >>> with Session() as ses:
-        ...     with ses.virtualfile_from_data(
-        ...         check_kind="vector", data=data
-        ...     ) as fin:
+        ...     with ses.virtualfile_from_data(check_kind="vector", data=data) as fin:
         ...         # Send the output to a file so that we can read it
         ...         with GMTTempFile() as fout:
         ...             ses.call_module("info", fin + " ->" + fout.name)
         ...             print(fout.read().strip())
-        ...
         <vector memory>: N = 3 <7/9> <4/6> <1/3>
         """
         kind = data_kind(
@@ -1556,8 +1555,8 @@ class Session:
 
         # Decide which virtualfile_from_ function to use
         _virtualfile_from = {
-            "file": nullcontext,
-            "arg": nullcontext,
+            "file": contextlib.nullcontext,
+            "arg": contextlib.nullcontext,
             "geojson": tempfile_from_geojson,
             "grid": self.virtualfile_from_grid,
             "image": tempfile_from_image,
@@ -1587,23 +1586,19 @@ class Session:
             if extra_arrays:
                 _data.extend(extra_arrays)
         elif kind == "matrix":  # turn 2-D arrays into list of vectors
-            try:
-                # pandas.Series will be handled below like a 1-D numpy.ndarray
-                assert not hasattr(data, "to_frame")
-                # pandas.DataFrame and xarray.Dataset types
+            if hasattr(data, "items") and not hasattr(data, "to_frame"):
+                # pandas.DataFrame or xarray.Dataset types.
+                # pandas.Series will be handled below like a 1-D numpy.ndarray.
                 _data = [array for _, array in data.items()]
-            except (AttributeError, AssertionError):
-                try:
-                    # Just use virtualfile_from_matrix for 2-D numpy.ndarray
-                    # which are signed integer (i), unsigned integer (u) or
-                    # floating point (f) types
-                    assert data.ndim == 2 and data.dtype.kind in "iuf"
-                    _virtualfile_from = self.virtualfile_from_matrix
-                    _data = (data,)
-                except (AssertionError, AttributeError):
-                    # Python list, tuple, numpy.ndarray, and pandas.Series
-                    # types
-                    _data = np.atleast_2d(np.asanyarray(data).T)
+            elif hasattr(data, "ndim") and data.ndim == 2 and data.dtype.kind in "iuf":
+                # Just use virtualfile_from_matrix for 2-D numpy.ndarray
+                # which are signed integer (i), unsigned integer (u) or
+                # floating point (f) types
+                _virtualfile_from = self.virtualfile_from_matrix
+                _data = (data,)
+            else:
+                # Python list, tuple, numpy.ndarray, and pandas.Series types
+                _data = np.atleast_2d(np.asanyarray(data).T)
 
         # Finally create the virtualfile from the data, to be passed into GMT
         file_context = _virtualfile_from(*_data)
@@ -1636,7 +1631,6 @@ class Session:
         ... )
         >>> with Session() as lib:
         ...     wesn = lib.extract_region()
-        ...
         >>> print(", ".join([f"{x:.2f}" for x in wesn]))
         0.00, 10.00, -20.00, -10.00
 
@@ -1644,12 +1638,9 @@ class Session:
         Hawaiʻi):
 
         >>> fig = pygmt.Figure()
-        >>> fig.coast(
-        ...     region="US.HI", projection="M6i", frame=True, land="black"
-        ... )
+        >>> fig.coast(region="US.HI", projection="M6i", frame=True, land="black")
         >>> with Session() as lib:
         ...     wesn = lib.extract_region()
-        ...
         >>> print(", ".join([f"{x:.2f}" for x in wesn]))
         -164.71, -154.81, 18.91, 23.58
 
@@ -1658,15 +1649,12 @@ class Session:
         region to multiples of 5):
 
         >>> fig = pygmt.Figure()
-        >>> fig.coast(
-        ...     region="US.HI+r5", projection="M6i", frame=True, land="black"
-        ... )
+        >>> fig.coast(region="US.HI+r5", projection="M6i", frame=True, land="black")
         >>> with Session() as lib:
         ...     wesn = lib.extract_region()
-        ...
         >>> print(", ".join([f"{x:.2f}" for x in wesn]))
         -165.00, -150.00, 15.00, 25.00
-        """
+        """  # noqa: RUF002
         c_extract_region = self.get_libgmt_func(
             "GMT_Extract_Region",
             argtypes=[ctp.c_void_p, ctp.c_char_p, ctp.POINTER(ctp.c_double)],
