@@ -1,9 +1,11 @@
 """
-Function to download the IGPP Global Earth Free-Air Anomaly datasets from the
-GMT data server, and load as :class:`xarray.DataArray`.
+Function to download the IGPP Earth Free-Air Anomaly dataset from the GMT data server,
+and load as :class:`xarray.DataArray`.
 
 The grids are available in various resolutions.
 """
+from typing import Literal
+
 from pygmt.datasets.load_remote_dataset import _load_remote_dataset
 from pygmt.helpers import kwargs_to_strings
 
@@ -11,9 +13,19 @@ __doctest_skip__ = ["load_earth_free_air_anomaly"]
 
 
 @kwargs_to_strings(region="sequence")
-def load_earth_free_air_anomaly(resolution="01d", region=None, registration=None):
+def load_earth_free_air_anomaly(
+    resolution="01d",
+    region=None,
+    registration: Literal["gridline", "pixel", None] = None,
+):
     r"""
-    Load an Earth Free-Air Anomaly grid in various resolutions.
+    Load the IGPP Earth Free-Air Anomaly dataset in various resolutions.
+
+    .. figure:: https://www.generic-mapping-tools.org/remote-datasets/_images/GMT_earth_faa.jpg
+       :width: 80 %
+       :align: center
+
+       IGPP Earth Free-Air Anomaly dataset.
 
     The grids are downloaded to a user data directory
     (usually ``~/.gmt/server/earth/earth_faa/``) the first time you invoke
@@ -21,19 +33,20 @@ def load_earth_free_air_anomaly(resolution="01d", region=None, registration=None
     So you'll need an internet connection the first time around.
 
     These grids can also be accessed by passing in the file name
-    **@earth_faa**\_\ *res*\[_\ *reg*] to any grid plotting/processing
-    function. *res* is the grid resolution (see below), and *reg* is grid
-    registration type (**p** for pixel registration or **g** for gridline
-    registration).
+    **@earth_faa**\_\ *res*\[_\ *reg*] to any grid processing function or
+    plotting method. *res* is the grid resolution (see below), and *reg* is
+    the grid registration type (**p** for pixel registration or **g** for
+    gridline registration).
 
     The default color palette table (CPT) for this dataset is *@earth_faa.cpt*.
     It's implicitly used when passing in the file name of the dataset to any
     grid plotting method if no CPT is explicitly specified. When the dataset
     is loaded and plotted as an :class:`xarray.DataArray` object, the default
-    CPT is ignored and GMT's default CPT (*turbo*) is used. To use the
+    CPT is ignored, and GMT's default CPT (*turbo*) is used. To use the
     dataset-specific CPT, you need to explicitly set ``cmap="@earth_faa.cpt"``.
 
-    Refer to :gmt-datasets:`earth-faa.html` for more details.
+    Refer to :gmt-datasets:`earth-faa.html` for more details about available
+    datasets, including version information and references.
 
     Parameters
     ----------
@@ -49,10 +62,11 @@ def load_earth_free_air_anomaly(resolution="01d", region=None, registration=None
         Required for grids with resolutions higher than 5
         arc-minutes (i.e., ``"05m"``).
 
-    registration : str
+    registration
         Grid registration type. Either ``"pixel"`` for pixel registration or
-        ``"gridline"`` for gridline registration. Default is ``"gridline"``
-        for all resolutions except ``"01m"`` which is ``"pixel"`` only.
+        ``"gridline"`` for gridline registration. Default is ``None``, means
+        ``"gridline"`` for all resolutions except ``"01m"`` which is
+        ``"pixel"`` only.
 
     Returns
     -------
@@ -78,9 +92,7 @@ def load_earth_free_air_anomaly(resolution="01d", region=None, registration=None
     >>> # load the default grid (gridline-registered 1 arc-degree grid)
     >>> grid = load_earth_free_air_anomaly()
     >>> # load the 30 arc-minutes grid with "gridline" registration
-    >>> grid = load_earth_free_air_anomaly(
-    ...     resolution="30m", registration="gridline"
-    ... )
+    >>> grid = load_earth_free_air_anomaly(resolution="30m", registration="gridline")
     >>> # load high-resolution (5 arc-minutes) grid for a specific region
     >>> grid = load_earth_free_air_anomaly(
     ...     resolution="05m",
