@@ -1,9 +1,11 @@
 """
-Function to download the EGM2008 Global Earth Geoid from the GMT data server,
-and load as :class:`xarray.DataArray`.
+Function to download the EGM2008 Earth Geoid dataset from the GMT data server, and load
+as :class:`xarray.DataArray`.
 
 The grids are available in various resolutions.
 """
+from typing import Literal
+
 from pygmt.datasets.load_remote_dataset import _load_remote_dataset
 from pygmt.helpers import kwargs_to_strings
 
@@ -11,9 +13,19 @@ __doctest_skip__ = ["load_earth_geoid"]
 
 
 @kwargs_to_strings(region="sequence")
-def load_earth_geoid(resolution="01d", region=None, registration=None):
+def load_earth_geoid(
+    resolution="01d",
+    region=None,
+    registration: Literal["gridline", "pixel"] = "gridline",
+):
     r"""
-    Load the EGM2008 Global Earth Geoid in various resolutions.
+    Load the EGM2008 Earth Geoid dataset in various resolutions.
+
+    .. figure:: https://www.generic-mapping-tools.org/remote-datasets/_images/GMT_earth_geoid.jpg
+       :width: 80 %
+       :align: center
+
+       EGM2008 Earth Geoid dataset.
 
     The grids are downloaded to a user data directory
     (usually ``~/.gmt/server/earth/earth_geoid/``) the first time you invoke
@@ -21,12 +33,13 @@ def load_earth_geoid(resolution="01d", region=None, registration=None):
     So you'll need an internet connection the first time around.
 
     These grids can also be accessed by passing in the file name
-    **@earth_geoid**\_\ *res*\[_\ *reg*] to any grid plotting/processing
-    function. *res* is the grid resolution (see below), and *reg* is grid
-    registration type (**p** for pixel registration or **g** for gridline
-    registration).
+    **@earth_geoid**\_\ *res*\[_\ *reg*] to any grid processing function or
+    plotting method. *res* is the grid resolution (see below), and *reg* is
+    the grid registration type (**p** for pixel registration or **g** for
+    gridline registration).
 
-    Refer to :gmt-datasets:`earth-geoid.html` for more details.
+    Refer to :gmt-datasets:`earth-geoid.html` for more details about available
+    datasets, including version information and references.
 
     Parameters
     ----------
@@ -42,9 +55,9 @@ def load_earth_geoid(resolution="01d", region=None, registration=None):
         Required for grids with resolutions higher than 5
         arc-minutes (i.e., ``"05m"``).
 
-    registration : str
+    registration
         Grid registration type. Either ``"pixel"`` for pixel registration or
-        ``"gridline"`` for gridline registration. Default is ``"gridline"``.
+        ``"gridline"`` for gridline registration.
 
     Returns
     -------
