@@ -8,8 +8,10 @@ from tempfile import TemporaryDirectory
 
 try:
     import IPython
+
+    _HAS_IPYTHON = True
 except ImportError:
-    IPython = None  # pylint: disable=invalid-name
+    _HAS_IPYTHON = False
 
 
 from pygmt.clib import Session
@@ -33,8 +35,8 @@ SHOW_CONFIG = {
 }
 
 # Show figures in Jupyter notebooks if available
-if IPython:
-    get_ipython = IPython.get_ipython()  # pylint: disable=invalid-name
+if _HAS_IPYTHON:
+    get_ipython = IPython.get_ipython()
     if get_ipython and "IPKernelApp" in get_ipython.config:  # Jupyter Notebook enabled
         SHOW_CONFIG["method"] = "notebook"
 
@@ -82,13 +84,13 @@ class Figure:
 
     def __init__(self):
         self._name = unique_name()
-        self._preview_dir = TemporaryDirectory(  # pylint: disable=consider-using-with
-            prefix=f"{self._name}-preview-"
-        )
+        self._preview_dir = TemporaryDirectory(prefix=f"{self._name}-preview-")
         self._activate_figure()
 
     def __del__(self):
-        # Clean up the temporary directory that stores the previews
+        """
+        Clean up the temporary directory that stores the previews.
+        """
         if hasattr(self, "_preview_dir"):
             self._preview_dir.cleanup()
 
@@ -110,8 +112,8 @@ class Figure:
 
     def _preprocess(self, **kwargs):
         """
-        Call the ``figure`` module before each plotting command to ensure we're
-        plotting to this particular figure.
+        Call the ``figure`` module before each plotting command to ensure we're plotting
+        to this particular figure.
         """
         self._activate_figure()
         return kwargs
@@ -251,18 +253,38 @@ class Figure:
                 module="psconvert", args=f"{prefix_arg} {build_arg_string(kwargs)}"
             )
 
-    def savefig(
-        self, fname, transparent=False, crop=True, anti_alias=True, show=False, **kwargs
+    def savefig(  # noqa: PLR0912
+        self,
+        fname,
+        transparent=False,
+        crop=True,
+        anti_alias=True,
+        show=False,
+        worldfile=False,
+        **kwargs,
     ):
         """
-        Save the figure to a file.
+        Save the figure to an image file.
 
-        This method implements a matplotlib-like interface for
-        :meth:`pygmt.Figure.psconvert`.
+        Supported image formats and their extensions:
 
-        Supported formats: PNG (``.png``), JPEG (``.jpg``), PDF (``.pdf``),
-        BMP (``.bmp``), TIFF (``.tif``), EPS (``.eps``), and KML (``.kml``).
-        The KML output generates a companion PNG file.
+        **Raster image formats**
+
+        - BMP (``.bmp``)
+        - JPEG (``.jpg`` or ``.jpeg``)
+        - GeoTIFF (``.tiff``)
+        - PNG (``.png``)
+        - PPM (``.ppm``)
+        - TIFF (``.tif``)
+
+        **Vector image formats**
+
+        - EPS (``.eps``)
+        - PDF (``.pdf``)
+
+        Beside the above formats, you can also save the figure to a KML file
+        (``.kml``), with a companion PNG file generated automatically. The KML
+        file can be viewed in Google Earth.
 
         You can pass in any keyword arguments that
         :meth:`pygmt.Figure.psconvert` accepts.
@@ -278,13 +300,20 @@ class Figure:
         crop : bool
             If ``True``, will crop the figure canvas (page) to the plot area.
         anti_alias: bool
-            If ``True``, will use anti-aliasing when creating raster images
-            (PNG, JPG, TIFF). More specifically, it passes arguments ``t2``
-            and ``g2`` to the ``anti_aliasing`` parameter of
-            :meth:`pygmt.Figure.psconvert`. Ignored if creating vector
-            graphics.
+            If ``True``, will use anti-aliasing when creating raster images.
+            More specifically, it passes the arguments ``"t2"`` and ``"g2"``
+            to the ``anti_aliasing`` parameter of
+            :meth:`pygmt.Figure.psconvert`. Ignored if creating vector images.
         show: bool
             If ``True``, will open the figure in an external viewer.
+        worldfile : bool
+            If ``True``, will create a companion
+            `world file <https://en.wikipedia.org/wiki/World_file>`__ for the
+            figure. The world file will have the same name as the figure file
+            but with different extension (e.g. tfw for tif). See
+            https://en.wikipedia.org/wiki/World_file#Filename_extension
+            for the convention of world file extensions. This parameter only
+            works for raster image formats (except GeoTIFF).
         dpi : int
             Set raster resolution in dpi [Default is ``720`` for PDF, ``300``
             for others].
@@ -295,17 +324,28 @@ class Figure:
         """
         # All supported formats
         fmts = {
-            "png": "g",
-            "pdf": "f",
-            "jpg": "j",
             "bmp": "b",
             "eps": "e",
-            "tif": "t",
+            "jpg": "j",
             "kml": "g",
+            "pdf": "f",
+            "png": "g",
+            "ppm": "m",
+            "tif": "t",
+            "tiff": None,  # GeoTIFF doesn't need the -T option
         }
 
-        prefix, ext = os.path.splitext(fname)
-        ext = ext[1:]  # Remove the .
+        fname = Path(fname)
+        prefix, suffix = fname.with_suffix("").as_posix(), fname.suffix
+        ext = suffix[1:].lower()  # Remove the . and normalize to lowercase
+
+        if ext == "jpeg":  # Alias jpeg to jpg
+            ext = "jpg"
+        elif ext == "tiff":  # GeoTIFF
+            kwargs["W"] = "+g"
+        elif ext == "kml":  # KML
+            kwargs["W"] = "+k"
+
         if ext not in fmts:
             if ext == "ps":
                 raise GMTInvalidInput(
@@ -323,10 +363,26 @@ class Figure:
         if anti_alias:
             kwargs["Qt"] = 2
             kwargs["Qg"] = 2
-        if ext == "kml":
-            kwargs["W"] = "+k"
+
+        if worldfile:
+            if ext in ["eps", "kml", "pdf", "tiff"]:
+                raise GMTInvalidInput(
+                    f"Saving a world file is not supported for '{ext}' format."
+                )
+            kwargs["W"] = True
 
         self.psconvert(prefix=prefix, fmt=fmt, crop=crop, **kwargs)
+
+        # Remove the .pgw world file if exists
+        # Not necessary after GMT 6.5.0.
+        # See upstream fix https://github.com/GenericMappingTools/gmt/pull/7865
+        if ext == "tiff" and fname.with_suffix(".pgw").exists():
+            fname.with_suffix(".pgw").unlink()
+
+        # Rename if file extension doesn't match the input file suffix
+        if ext != suffix[1:]:
+            fname.with_suffix("." + ext).rename(fname)
+
         if show:
             launch_external_viewer(fname)
 
@@ -392,20 +448,16 @@ class Figure:
 
         if method not in ["external", "notebook", "none"]:
             raise GMTInvalidInput(
-                (
-                    f"Invalid display method '{method}', "
-                    "should be either 'notebook', 'external', or 'none'."
-                )
+                f"Invalid display method '{method}', "
+                "should be either 'notebook', 'external', or 'none'."
             )
 
         if method == "notebook":
-            if IPython is None:
+            if not _HAS_IPYTHON:
                 raise GMTError(
-                    (
-                        "Notebook display is selected, but IPython is not available. "
-                        "Make sure you have IPython installed, "
-                        "or run the script in a Jupyter notebook."
-                    )
+                    "Notebook display is selected, but IPython is not available. "
+                    "Make sure you have IPython installed, "
+                    "or run the script in a Jupyter notebook."
                 )
             png = self._preview(
                 fmt="png", dpi=dpi, anti_alias=True, as_bytes=True, **kwargs
@@ -467,7 +519,7 @@ class Figure:
         html = '<img src="data:image/png;base64,{image}" width="{width}px">'
         return html.format(image=base64_png.decode("utf-8"), width=500)
 
-    from pygmt.src import (  # pylint: disable=import-outside-toplevel
+    from pygmt.src import (  # type: ignore [misc]
         basemap,
         coast,
         colorbar,
@@ -539,8 +591,6 @@ def set_display(method=None):
         SHOW_CONFIG["method"] = method
     elif method is not None:
         raise GMTInvalidInput(
-            (
-                f"Invalid display mode '{method}', "
-                "should be either 'notebook', 'external', 'none' or None."
-            )
+            f"Invalid display mode '{method}', "
+            "should be either 'notebook', 'external', 'none' or None."
         )
