@@ -15,81 +15,14 @@ from pygmt.exceptions import GMTInvalidInput
 from pygmt.helpers.utils import is_nonstr_iter
 
 COMMON_DOCSTRINGS = {
-    "region": r"""
-        region : str or list
-            *xmin/xmax/ymin/ymax*\ [**+r**][**+u**\ *unit*].
-            Specify the :doc:`region </tutorials/basics/regions>` of interest.""",
-    "projection": r"""
-        projection : str
-            *projcode*\[*projparams*/]\ *width*.
-            Select map :doc:`projection </projections/index>`.""",
     "area_thresh": r"""
-        area_thresh : int or float or str
+        area_thresh : float or str
             *min_area*\ [/*min_level*/*max_level*][**+a**\[**g**\|\ **i**]\
             [**s**\|\ **S**]][**+l**\|\ **r**][**+p**\ *percent*].
             Features with an area smaller than *min_area* in km\ :sup:`2` or of
             hierarchical level that is lower than *min_level* or higher than
             *max_level* will not be plotted [Default is ``"0/0/4"`` (all
             features)].""",
-    "frame": r"""
-        frame : bool or str or list
-            Set map boundary
-            :doc:`frame and axes attributes </tutorials/basics/frames>`. """,
-    "cmap": r"""
-        cmap : str
-           File name of a CPT file or a series of comma-separated colors
-           (e.g., *color1*,\ *color2*,\ *color3*) to build a linear continuous
-           CPT from those colors automatically.""",
-    "fill": r"""
-        fill : str
-            Set color or pattern for filling symbols or polygons
-            [Default is no fill].""",
-    "spacing": r"""
-        spacing : int or float or str or list or tuple
-            *x_inc*\ [**+e**\|\ **n**][/\ *y_inc*\ [**+e**\|\ **n**]].
-            *x_inc* [and optionally *y_inc*] is the grid spacing.
-
-            - **Geographical (degrees) coordinates**: Optionally, append an
-              increment unit. Choose among **m** to indicate arc-minutes or
-              **s** to indicate arc-seconds. If one of the units **e**, **f**,
-              **k**, **M**, **n** or **u** is appended instead, the increment
-              is assumed to be given in meter, foot, km, mile, nautical mile or
-              US survey foot, respectively, and will be converted to the
-              equivalent degrees longitude at the middle latitude of the region
-              (the conversion depends on :gmt-term:`PROJ_ELLIPSOID`). If
-              *y_inc* is given but set to 0 it will be reset equal to *x_inc*;
-              otherwise it will be converted to degrees latitude.
-
-            - **All coordinates**: If **+e** is appended then the corresponding
-              max *x* (*east*) or *y* (*north*) may be slightly adjusted to fit
-              exactly the given increment [by default the increment may be
-              adjusted slightly to fit the given domain]. Finally, instead of
-              giving an increment you may specify the *number of nodes* desired
-              by appending **+n** to the supplied integer argument; the
-              increment is then recalculated from the number of nodes, the
-              ``registration``, and the domain. The resulting increment value
-              depends on whether you have selected a gridline-registered or
-              pixel-registered grid; see :gmt-docs:`GMT File Formats
-              <cookbook/file-formats.html#gmt-file-formats>` for details.
-
-            **Note**: If ``region=grdfile`` is used then the grid spacing and
-            the registration have already been initialized; use ``spacing`` and
-            ``registration`` to override these values.""",
-    "verbose": r"""
-        verbose : bool or str
-            Select verbosity level [Default is **w**], which modulates the messages
-            written to stderr. Choose among 7 levels of verbosity:
-
-            - **q** - Quiet, not even fatal error messages are produced
-            - **e** - Error messages only
-            - **w** - Warnings [Default]
-            - **t** - Timings (report runtimes for time-intensive algorithms)
-            - **i** - Informational messages (same as ``verbose=True``)
-            - **c** - Compatibility warnings
-            - **d** - Debugging messages""",
-    "pen": r"""
-        pen : str
-            Set pen attributes for lines or the outline of symbols.""",
     "aspatial": r"""
         aspatial : bool or str
             [*col*\ =]\ *name*\ [,...].
@@ -124,24 +57,45 @@ COMMON_DOCSTRINGS = {
                   be read as little- or big-endian, respectively.
 
             Full documentation is at :gmt-docs:`gmt.html#bi-full`.""",
-    "nodata": r"""
-        nodata : str
-            **i**\|\ **o**\ *nodata*.
-            Substitute specific values with NaN (for tabular data). For
-            example, ``nodata="-9999"`` will replace all values equal to -9999
-            with NaN during input and all NaN values with -9999 during output.
-            Prepend **i** to the *nodata* value for input columns only. Prepend
-            **o** to the *nodata* value for output columns only.""",
-    "panel": r"""
-        panel : bool or int or list
-            [*row,col*\|\ *index*].
-            Select a specific subplot panel. Only allowed when in subplot
-            mode. Use ``panel=True`` to advance to the next panel in the
-            selected order. Instead of *row,col* you may also give a scalar
-            value *index* which depends on the order you set via ``autolabel``
-            when the subplot was defined. **Note**: *row*, *col*, and *index*
-            all start at 0.
-         """,
+    "cmap": r"""
+        cmap : str
+           File name of a CPT file or a series of comma-separated colors
+           (e.g., *color1*,\ *color2*,\ *color3*) to build a linear continuous
+           CPT from those colors automatically.""",
+    "coltypes": r"""
+        coltypes : str
+            [**i**\|\ **o**]\ *colinfo*.
+            Specify data types of input and/or output columns (time or
+            geographical data). Full documentation is at
+            :gmt-docs:`gmt.html#f-full`.""",
+    "cores": r"""
+        cores : bool or int
+            [[**-**]\ *n*].
+            Limit the number of cores to be used in any OpenMP-enabled
+            multi-threaded algorithms. By default we try to use all available
+            cores. Set a number *n* to only use n cores (if too large it will
+            be truncated to the maximum cores available). Finally, give a
+            negative number *-n* to select (all - *n*) cores (or at least 1 if
+            *n* equals or exceeds all).
+            """,
+    "distcalc": r"""
+        distcalc : str
+            **e**\|\ **f**\|\ **g**.
+            Determine how spherical distances are calculated.
+
+            - **e** - Ellipsoidal (or geodesic) mode
+            - **f** - Flat Earth mode
+            - **g** - Great circle distance [Default]
+
+            All spherical distance calculations depend on the current ellipsoid
+            (:gmt-term:`PROJ_ELLIPSOID`), the definition of the mean radius
+            (:gmt-term:`PROJ_MEAN_RADIUS`), and the specification of latitude type
+            (:gmt-term:`PROJ_AUX_LATITUDE`). Geodesic distance calculations is also
+            controlled by method (:gmt-term:`PROJ_GEODESIC`).""",
+    "fill": r"""
+        fill : str
+            Set color or pattern for filling symbols or polygons
+            [Default is no fill].""",
     "find": r"""
         find : str
             [**~**]\ *"pattern"* \| [**~**]/\ *regexp*/[**i**].
@@ -150,12 +104,10 @@ COMMON_DOCSTRINGS = {
             the *pattern* or *regexp* to instead only pass data expressions
             that do not match the pattern. Append **i** for case insensitive
             matching. This does not apply to headers or segment headers.""",
-    "coltypes": r"""
-        coltypes : str
-            [**i**\|\ **o**]\ *colinfo*.
-            Specify data types of input and/or output columns (time or
-            geographical data). Full documentation is at
-            :gmt-docs:`gmt.html#f-full`.""",
+    "frame": r"""
+        frame : bool, str, or list
+            Set map boundary
+            :doc:`frame and axes attributes </tutorials/basics/frames>`. """,
     "gap": r"""
         gap : str or list
             **x**\|\ **y**\|\ **z**\|\ **d**\|\ **X**\|\ **Y**\|\
@@ -197,6 +149,13 @@ COMMON_DOCSTRINGS = {
                   column value must exceed *gap* for a break to be imposed.
                 - **+p** - specify that the current value minus the previous
                   value must exceed *gap* for a break to be imposed.""",
+    "grid": r"""
+        grid : str or xarray.DataArray
+            Name of the input grid file or the grid loaded as a
+            :class:`xarray.DataArray` object.
+
+            For reading a specific grid file format or applying basic data operations,
+            see :gmt-docs:`gmt.html#grd-inout-full` for the available modifiers.""",
     "header": r"""
         header : str
             [**i**\|\ **o**][*n*][**+c**][**+d**][**+m**\ *segheader*][**+r**\
@@ -249,24 +208,6 @@ COMMON_DOCSTRINGS = {
                   [Default is 1].
                 - **+o** to add the given *offset* to the input values [Default
                   is 0].""",
-    "distcalc": r"""
-        distcalc : str
-            **e**\|\ **f**\|\ **g**.
-            Determine how spherical distances are calculated.
-
-            - **e** - Ellipsoidal (or geodesic) mode
-            - **f** - Flat Earth mode
-            - **g** - Great circle distance [Default]
-
-            All spherical distance calculations depend on the current ellipsoid
-            (:gmt-term:`PROJ_ELLIPSOID`), the definition of the mean radius
-            (:gmt-term:`PROJ_MEAN_RADIUS`), and the specification of latitude type
-            (:gmt-term:`PROJ_AUX_LATITUDE`). Geodesic distance calculations is also
-            controlled by method (:gmt-term:`PROJ_GEODESIC`).""",
-    "label": r"""
-        label : str
-            Add a legend entry for the symbol or line being plotted. Full
-            documentation is at :gmt-docs:`gmt.html#l-full`.""",
     "interpolation": r"""
         interpolation : str
             [**b**\|\ **c**\|\ **l**\|\ **n**][**+a**][**+b**\ *BC*][**+c**][**+t**\ *threshold*].
@@ -277,6 +218,18 @@ COMMON_DOCSTRINGS = {
             - **c** for bicubic [Default]
             - **l** for bilinear
             - **n** for nearest-neighbor""",
+    "label": r"""
+        label : str
+            Add a legend entry for the symbol or line being plotted. Full
+            documentation is at :gmt-docs:`gmt.html#l-full`.""",
+    "nodata": r"""
+        nodata : str
+            **i**\|\ **o**\ *nodata*.
+            Substitute specific values with NaN (for tabular data). For
+            example, ``nodata="-9999"`` will replace all values equal to -9999
+            with NaN during input and all NaN values with -9999 during output.
+            Prepend **i** to the *nodata* value for input columns only. Prepend
+            **o** to the *nodata* value for output columns only.""",
     "outcols": r"""
         outcols : str or 1-D array
             *cols*\ [,...][,\ **t**\ [*word*]].
@@ -300,6 +253,24 @@ COMMON_DOCSTRINGS = {
               input and skip trailing text. **Note**: If ``incols`` is also
               used then the columns given to ``outcols`` correspond to the
               order after the ``incols`` selection has taken place.""",
+    "outgrid": """
+        outgrid : str or None
+            Name of the output netCDF grid file. For writing a specific grid
+            file format or applying basic data operations to the output grid,
+            see :gmt-docs:`gmt.html#grd-inout-full` for the available modifiers.""",
+    "panel": r"""
+        panel : bool, int, or list
+            [*row,col*\|\ *index*].
+            Select a specific subplot panel. Only allowed when in subplot
+            mode. Use ``panel=True`` to advance to the next panel in the
+            selected order. Instead of *row,col* you may also give a scalar
+            value *index* which depends on the order you set via ``autolabel``
+            when the subplot was defined. **Note**: *row*, *col*, and *index*
+            all start at 0.
+         """,
+    "pen": r"""
+        pen : str
+            Set pen attributes for lines or the outline of symbols.""",
     "perspective": r"""
         perspective : list or str
             [**x**\|\ **y**\|\ **z**]\ *azim*\[/*elev*\[/*zlevel*]]\
@@ -308,6 +279,14 @@ COMMON_DOCSTRINGS = {
             the viewpoint [Default is ``[180, 90]``]. Full documentation is at
             :gmt-docs:`gmt.html#perspective-full`.
         """,
+    "projection": r"""
+        projection : str
+            *projcode*\[*projparams*/]\ *width*\|\ *scale*.
+            Select map :doc:`projection </projections/index>`.""",
+    "region": r"""
+        region : str or list
+            *xmin/xmax/ymin/ymax*\ [**+r**][**+u**\ *unit*].
+            Specify the :doc:`region </tutorials/basics/regions>` of interest.""",
     "registration": r"""
         registration : str
             **g**\|\ **p**.
@@ -330,13 +309,56 @@ COMMON_DOCSTRINGS = {
                 - **+a** to suppress the output of the record if just one or
                   more of the columns equal NaN [Default skips record only
                   if values in all specified *cols* equal NaN].""",
+    "spacing": r"""
+        spacing : float, str, or list
+            *x_inc*\ [**+e**\|\ **n**][/\ *y_inc*\ [**+e**\|\ **n**]].
+            *x_inc* [and optionally *y_inc*] is the grid spacing.
+
+            - **Geographical (degrees) coordinates**: Optionally, append an
+              increment unit. Choose among **m** to indicate arc-minutes or
+              **s** to indicate arc-seconds. If one of the units **e**, **f**,
+              **k**, **M**, **n** or **u** is appended instead, the increment
+              is assumed to be given in meter, foot, km, mile, nautical mile or
+              US survey foot, respectively, and will be converted to the
+              equivalent degrees longitude at the middle latitude of the region
+              (the conversion depends on :gmt-term:`PROJ_ELLIPSOID`). If
+              *y_inc* is given but set to 0 it will be reset equal to *x_inc*;
+              otherwise it will be converted to degrees latitude.
+
+            - **All coordinates**: If **+e** is appended then the corresponding
+              max *x* (*east*) or *y* (*north*) may be slightly adjusted to fit
+              exactly the given increment [by default the increment may be
+              adjusted slightly to fit the given domain]. Finally, instead of
+              giving an increment you may specify the *number of nodes* desired
+              by appending **+n** to the supplied integer argument; the
+              increment is then recalculated from the number of nodes, the
+              ``registration``, and the domain. The resulting increment value
+              depends on whether you have selected a gridline-registered or
+              pixel-registered grid; see :gmt-docs:`GMT File Formats
+              <reference/file-formats.html#gmt-file-formats>` for details.
+
+            **Note**: If ``region=grdfile`` is used then the grid spacing and
+            the registration have already been initialized; use ``spacing`` and
+            ``registration`` to override these values.""",
     "transparency": r"""
-        transparency : int or float
+        transparency : float
             Set transparency level, in [0-100] percent range
             [Default is ``0``, i.e., opaque].
             Only visible when PDF or raster format output is selected.
             Only the PNG format selection adds a transparency layer
             in the image (for further processing). """,
+    "verbose": r"""
+        verbose : bool or str
+            Select verbosity level [Default is **w**], which modulates the messages
+            written to stderr. Choose among 7 levels of verbosity:
+
+            - **q** - Quiet, not even fatal error messages are produced
+            - **e** - Error messages only
+            - **w** - Warnings [Default]
+            - **t** - Timings (report runtimes for time-intensive algorithms)
+            - **i** - Informational messages (same as ``verbose=True``)
+            - **c** - Compatibility warnings
+            - **d** - Debugging messages""",
     "wrap": r"""
         wrap : str
             **y**\|\ **a**\|\ **w**\|\ **d**\|\ **h**\|\ **m**\|\ **s**\|\
@@ -355,16 +377,6 @@ COMMON_DOCSTRINGS = {
                 - **c** - custom cycle (normalized)
 
             Full documentation is at :gmt-docs:`gmt.html#w-full`.""",
-    "cores": r"""
-        cores : bool or int
-            [[**-**]\ *n*].
-            Limit the number of cores to be used in any OpenMP-enabled
-            multi-threaded algorithms. By default we try to use all available
-            cores. Set a number *n* to only use n cores (if too large it will
-            be truncated to the maximum cores available). Finally, give a
-            negative number *-n* to select (all - *n*) cores (or at least 1 if
-            *n* equals or exceeds all).
-            """,
 }
 
 
@@ -400,7 +412,7 @@ def fmt_docstring(module_func):
     ...
     ...     Parameters
     ...     ----------
-    ...     data : str or {table-like}
+    ...     data : str, {table-like}
     ...         Pass in either a file name to an ASCII data table, a 2-D
     ...         {table-classes}.
     ...     {region}
@@ -409,14 +421,13 @@ def fmt_docstring(module_func):
     ...     {aliases}
     ...     '''
     ...     pass
-    ...
     >>> print(gmtinfo.__doc__)
     <BLANKLINE>
     My nice module.
     <BLANKLINE>
     Parameters
     ----------
-    data : str or numpy.ndarray or pandas.DataFrame or xarray.Dataset or geo...
+    data : str, numpy.ndarray, pandas.DataFrame, xarray.Dataset, or geo...
         Pass in either a file name to an ASCII data table, a 2-D
         :class:`numpy.ndarray`, a :class:`pandas.DataFrame`, an
         :class:`xarray.Dataset` made up of 1-D :class:`xarray.DataArray`
@@ -426,7 +437,7 @@ def fmt_docstring(module_func):
         *xmin/xmax/ymin/ymax*\ [**+r**][**+u**\ *unit*].
         Specify the :doc:`region </tutorials/basics/regions>` of interest.
     projection : str
-        *projcode*\[*projparams*/]\ *width*.
+        *projcode*\[*projparams*/]\ *width*\|\ *scale*.
         Select map :doc:`projection </projections/index>`.
     <BLANKLINE>
     **Aliases:**
@@ -434,7 +445,7 @@ def fmt_docstring(module_func):
     - J = projection
     - R = region
     <BLANKLINE>
-    """
+    """  # noqa: D410,D411
     filler_text = {}
 
     if hasattr(module_func, "aliases"):
@@ -444,14 +455,9 @@ def fmt_docstring(module_func):
             aliases.append(f"- {arg} = {alias}")
         filler_text["aliases"] = "\n".join(aliases)
 
-    filler_text["table-like"] = " or ".join(
-        [
-            "numpy.ndarray",
-            "pandas.DataFrame",
-            "xarray.Dataset",
-            "geopandas.GeoDataFrame",
-        ]
-    )
+    filler_text[
+        "table-like"
+    ] = "numpy.ndarray, pandas.DataFrame, xarray.Dataset, or geopandas.GeoDataFrame"
     filler_text["table-classes"] = (
         ":class:`numpy.ndarray`, a :class:`pandas.DataFrame`, an\n"
         "    :class:`xarray.Dataset` made up of 1-D :class:`xarray.DataArray`\n"
@@ -487,8 +493,8 @@ def _insert_alias(module_func, default_value=None):
             new_param = Parameter(
                 alias, kind=Parameter.KEYWORD_ONLY, default=default_value
             )
-            wrapped_params = wrapped_params + [new_param]
-    all_params = wrapped_params + [kwargs_param]
+            wrapped_params = [*wrapped_params, new_param]
+    all_params = [*wrapped_params, kwargs_param]
     # Update method signature
     sig_new = sig.replace(parameters=all_params)
     module_func.__signature__ = sig_new
@@ -519,7 +525,6 @@ def use_alias(**aliases):
     >>> @use_alias(R="region", J="projection")
     ... def my_module(**kwargs):
     ...     print("R =", kwargs["R"], "J =", kwargs["J"])
-    ...
     >>> my_module(R="bla", J="meh")
     R = bla J = meh
     >>> my_module(region="bla", J="meh")
@@ -634,10 +639,7 @@ def kwargs_to_strings(**conversions):
 
     Examples
     --------
-
-    >>> @kwargs_to_strings(
-    ...     R="sequence", i="sequence_comma", files="sequence_space"
-    ... )
+    >>> @kwargs_to_strings(R="sequence", i="sequence_comma", files="sequence_space")
     ... def module(*args, **kwargs):
     ...     "A module that prints the arguments it received"
     ...     print("{", end="")
@@ -684,20 +686,35 @@ def kwargs_to_strings(**conversions):
     ...     ]
     ... )
     {'R': '2005-01-01T08:00:00.000000000/2015-01-01T12:00:00.123456'}
+    >>> # Here is a more realistic example
+    >>> # See https://github.com/GenericMappingTools/pygmt/issues/2361
+    >>> @kwargs_to_strings(
+    ...     files="sequence_space",
+    ...     offset="sequence",
+    ...     R="sequence",
+    ...     i="sequence_comma",
+    ... )
+    ... def module(files, offset=("-54p", "-54p"), **kwargs):
+    ...     "A module that prints the arguments it received"
+    ...     print(files, end=" ")
+    ...     print(offset, end=" ")
+    ...     print("{", end="")
+    ...     print(
+    ...         ", ".join(f"'{k}': {repr(kwargs[k])}" for k in sorted(kwargs)),
+    ...         end="",
+    ...     )
+    ...     print("}")
+    >>> module(files=["data1.txt", "data2.txt"])
+    data1.txt data2.txt -54p/-54p {}
+    >>> module(["data1.txt", "data2.txt"])
+    data1.txt data2.txt -54p/-54p {}
+    >>> module(files=["data1.txt", "data2.txt"], offset=("20p", "20p"))
+    data1.txt data2.txt 20p/20p {}
+    >>> module(["data1.txt", "data2.txt"], ("20p", "20p"))
+    data1.txt data2.txt 20p/20p {}
+    >>> module(["data1.txt", "data2.txt"], ("20p", "20p"), R=[1, 2, 3, 4])
+    data1.txt data2.txt 20p/20p {'R': '1/2/3/4'}
     """
-    valid_conversions = [
-        "sequence",
-        "sequence_comma",
-        "sequence_plus",
-        "sequence_space",
-    ]
-
-    for arg, fmt in conversions.items():
-        if fmt not in valid_conversions:
-            raise GMTInvalidInput(
-                f"Invalid conversion type '{fmt}' for argument '{arg}'."
-            )
-
     separators = {
         "sequence": "/",
         "sequence_comma": ",",
@@ -705,37 +722,58 @@ def kwargs_to_strings(**conversions):
         "sequence_space": " ",
     }
 
+    for arg, fmt in conversions.items():
+        if fmt not in separators:
+            raise GMTInvalidInput(
+                f"Invalid conversion type '{fmt}' for argument '{arg}'."
+            )
+
     # Make the actual decorator function
     def converter(module_func):
         """
         The decorator that creates our new function with the conversions.
         """
+        sig = signature(module_func)
 
         @functools.wraps(module_func)
         def new_module(*args, **kwargs):
             """
             New module instance that converts the arguments first.
             """
+            # Inspired by https://stackoverflow.com/a/69170441
+            bound = sig.bind(*args, **kwargs)
+            bound.apply_defaults()
+
             for arg, fmt in conversions.items():
-                if arg in kwargs:
-                    value = kwargs[arg]
-                    issequence = fmt in separators
-                    if issequence and is_nonstr_iter(value):
-                        for index, item in enumerate(value):
-                            try:
-                                # check if there is a space " " when converting
-                                # a pandas.Timestamp/xr.DataArray to a string.
-                                # If so, use np.datetime_as_string instead.
-                                assert " " not in str(item)
-                            except AssertionError:
-                                # convert datetime-like item to ISO 8601
-                                # string format like YYYY-MM-DDThh:mm:ss.ffffff
-                                value[index] = np.datetime_as_string(
-                                    np.asarray(item, dtype=np.datetime64)
-                                )
-                        kwargs[arg] = separators[fmt].join(f"{item}" for item in value)
+                # The arg may be in args or kwargs
+                if arg in bound.arguments:
+                    value = bound.arguments[arg]
+                elif arg in bound.arguments.get("kwargs"):
+                    value = bound.arguments["kwargs"][arg]
+                else:
+                    continue
+
+                if fmt in separators and is_nonstr_iter(value):
+                    for index, item in enumerate(value):
+                        if " " in str(item):
+                            # Check if there is a space " " when converting
+                            # a pandas.Timestamp/xr.DataArray to a string.
+                            # If so, use np.datetime_as_string instead.
+                            # Convert datetime-like item to ISO 8601
+                            # string format like YYYY-MM-DDThh:mm:ss.ffffff.
+                            value[index] = np.datetime_as_string(
+                                np.asarray(item, dtype=np.datetime64)
+                            )
+                    newvalue = separators[fmt].join(f"{item}" for item in value)
+                    # Changes in bound.arguments will reflect in bound.args
+                    # and bound.kwargs.
+                    if arg in bound.arguments:
+                        bound.arguments[arg] = newvalue
+                    elif arg in bound.arguments.get("kwargs"):
+                        bound.arguments["kwargs"][arg] = newvalue
+
             # Execute the original function and return its output
-            return module_func(*args, **kwargs)
+            return module_func(*bound.args, **bound.kwargs)
 
         return new_module
 
@@ -771,7 +809,6 @@ def deprecate_parameter(oldname, newname, deprecate_version, remove_version):
     ... def module(data, size=0, **kwargs):
     ...     "A module that prints the arguments it received"
     ...     print(f"data={data}, size={size}, color={kwargs['color']}")
-    ...
     >>> # new names are supported
     >>> module(data="table.txt", size=5.0, color="red")
     data=table.txt, size=5.0, color=red
@@ -783,19 +820,17 @@ def deprecate_parameter(oldname, newname, deprecate_version, remove_version):
     ...     for i in range(len(w)):
     ...         assert issubclass(w[i].category, FutureWarning)
     ...         assert "deprecated" in str(w[i].message)
-    ...
     data=table.txt, size=5.0, color=red
     >>> # using both old and new names will raise an GMTInvalidInput exception
     >>> import pytest
     >>> with pytest.raises(GMTInvalidInput):
     ...     module(data="table.txt", size=5.0, sizes=4.0)
-    ...
     """
 
     def deprecator(module_func):
         """
-        The decorator that creates the new function to work with both old and
-        new parameters.
+        The decorator that creates the new function to work with both old and new
+        parameters.
         """
 
         @functools.wraps(module_func)
