@@ -43,7 +43,6 @@ def _blockm(block_method, data, x, y, z, outfile, **kwargs):
     """
     with GMTTempFile(suffix=".csv") as tmpfile:
         with Session() as lib:
-            # Choose how data will be passed into the module
             table_context = lib.virtualfile_from_data(
                 check_kind="vector", data=data, x=x, y=y, z=z, required_z=True
             )
@@ -106,7 +105,7 @@ def blockmean(data=None, x=None, y=None, z=None, outfile=None, **kwargs):
 
     Parameters
     ----------
-    data : str or {table-like}
+    data : str, {table-like}
         Pass in (x, y, z) or (longitude, latitude, elevation) values by
         providing a file name to an ASCII data table, a 2-D
         {table-classes}.
@@ -156,10 +155,8 @@ def blockmean(data=None, x=None, y=None, z=None, outfile=None, **kwargs):
     >>> import pygmt
     >>> # Load a table of ship observations of bathymetry off Baja California
     >>> data = pygmt.datasets.load_sample_data(name="bathymetry")
-    >>> # Calculate block mean values within 5 by 5 minute bins
-    >>> data_bmean = pygmt.blockmean(
-    ...     data=data, region=[245, 255, 20, 30], spacing="5m"
-    ... )
+    >>> # Calculate block mean values within 5 by 5 arc-minute bins
+    >>> data_bmean = pygmt.blockmean(data=data, region=[245, 255, 20, 30], spacing="5m")
     """
     return _blockm(
         block_method="blockmean", data=data, x=x, y=y, z=z, outfile=outfile, **kwargs
@@ -202,7 +199,7 @@ def blockmedian(data=None, x=None, y=None, z=None, outfile=None, **kwargs):
 
     Parameters
     ----------
-    data : str or {table-like}
+    data : str, {table-like}
         Pass in (x, y, z) or (longitude, latitude, elevation) values by
         providing a file name to an ASCII data table, a 2-D
         {table-classes}.
@@ -243,7 +240,7 @@ def blockmedian(data=None, x=None, y=None, z=None, outfile=None, **kwargs):
     >>> import pygmt
     >>> # Load a table of ship observations of bathymetry off Baja California
     >>> data = pygmt.datasets.load_sample_data(name="bathymetry")
-    >>> # Calculate block median values within 5 by 5 minute bins
+    >>> # Calculate block median values within 5 by 5 arc-minute bins
     >>> data_bmedian = pygmt.blockmedian(
     ...     data=data, region=[245, 255, 20, 30], spacing="5m"
     ... )
@@ -289,7 +286,7 @@ def blockmode(data=None, x=None, y=None, z=None, outfile=None, **kwargs):
 
     Parameters
     ----------
-    data : str or {table-like}
+    data : str, {table-like}
         Pass in (x, y, z) or (longitude, latitude, elevation) values by
         providing a file name to an ASCII data table, a 2-D
         {table-classes}.
@@ -330,10 +327,8 @@ def blockmode(data=None, x=None, y=None, z=None, outfile=None, **kwargs):
     >>> import pygmt
     >>> # Load a table of ship observations of bathymetry off Baja California
     >>> data = pygmt.datasets.load_sample_data(name="bathymetry")
-    >>> # Calculate block mode values within 5 by 5 minute bins
-    >>> data_bmode = pygmt.blockmode(
-    ...     data=data, region=[245, 255, 20, 30], spacing="5m"
-    ... )
+    >>> # Calculate block mode values within 5 by 5 arc-minute bins
+    >>> data_bmode = pygmt.blockmode(data=data, region=[245, 255, 20, 30], spacing="5m")
     """
     return _blockm(
         block_method="blockmode", data=data, x=x, y=y, z=z, outfile=outfile, **kwargs
