@@ -2,6 +2,7 @@
 grdimage - Plot grids or images.
 """
 from pygmt.clib import Session
+from pygmt.exceptions import GMTInvalidInput
 from pygmt.helpers import (
     build_arg_string,
     deprecate_parameter,
@@ -16,7 +17,6 @@ __doctest_skip__ = ["grdimage"]
 @fmt_docstring
 @deprecate_parameter("bit_color", "bitcolor", "v0.10.0", remove_version="v0.12.0")
 @use_alias(
-    A="img_out",
     B="frame",
     C="cmap",
     D="img_in",
@@ -75,25 +75,7 @@ def grdimage(self, grid, **kwargs):
 
     Parameters
     ----------
-    grid : str or xarray.DataArray
-        The file name or a DataArray containing the input 2-D gridded data
-        set or image to be plotted (See GRID FILE FORMATS at
-        :gmt-docs:`grdimage.html#grid-file-formats`).
-    img_out : str
-        *out_img*\[=\ *driver*].
-        Save an image in a raster format instead of PostScript. Append
-        *out_img* to select the image file name and extension. If the
-        extension is one of .bmp, .gif, .jpg, .png, or .tif then no driver
-        information is required. For other output formats you must append
-        the required GDAL driver. The *driver* is the driver code name used
-        by GDAL; see your GDAL installation's documentation for available
-        drivers. Append a **+c**\ *args* string where *args* is a list
-        of one or more concatenated number of GDAL **-co** arguments. For
-        example, to write a GeoPDF with the TerraGo format use
-        ``=PDF+cGEO_ENCODING=OGC_BP``. **Notes**: (1) If a tiff file (.tif)
-        is selected then we will write a GeoTiff image if the GMT
-        projection syntax translates into a PROJ syntax, otherwise a plain
-        tiff file is produced. (2) Any vector elements will be lost.
+    {grid}
     {frame}
     {cmap}
     img_in : str
@@ -173,7 +155,14 @@ def grdimage(self, grid, **kwargs):
     >>> # show the plot
     >>> fig.show()
     """
-    kwargs = self._preprocess(**kwargs)  # pylint: disable=protected-access
+    kwargs = self._preprocess(**kwargs)
+
+    # Do not support -A option
+    if any(kwargs.get(arg) is not None for arg in ["A", "img_out"]):
+        raise GMTInvalidInput(
+            "Parameter 'img_out'/'A' is not implemented. "
+            "Please consider submitting a feature request to us."
+        )
 
     with Session() as lib:
         with lib.virtualfile_from_data(
