@@ -51,11 +51,8 @@ def grdsample(grid, **kwargs):
 
     Parameters
     ----------
-    grid : str or xarray.DataArray
-        The file name of the input grid or the grid loaded as a DataArray.
-    outgrid : str or None
-        The name of the output netCDF file with extension .nc to store the grid
-        in.
+    {grid}
+    {outgrid}
     {spacing}
     {region}
     translate : bool
@@ -81,16 +78,14 @@ def grdsample(grid, **kwargs):
     Example
     -------
     >>> import pygmt
-    >>> # Load a grid of @earth_relief_30m data, with an x-range of 10 to 30,
-    >>> # and a y-range of 15 to 25
+    >>> # Load a grid of @earth_relief_30m data, with a longitude range of
+    >>> # 10° E to 30° E, and a latitude range of 15° N to 25° N
     >>> grid = pygmt.datasets.load_earth_relief(
     ...     resolution="30m", region=[10, 30, 15, 25]
     ... )
     >>> # Create a new grid from an input grid, change the registration,
-    >>> # and set both x- and y-spacing to 0.5 degrees
-    >>> new_grid = pygmt.grdsample(
-    ...     grid=grid, translate=True, spacing=[0.5, 0.5]
-    ... )
+    >>> # and set both x- and y-spacing to 0.5 arc-degrees
+    >>> new_grid = pygmt.grdsample(grid=grid, translate=True, spacing=[0.5, 0.5])
     """
     with GMTTempFile(suffix=".nc") as tmpfile:
         with Session() as lib:
