@@ -3,13 +3,13 @@ grdvolume - Calculate grid volume and area constrained by a contour.
 """
 import pandas as pd
 from pygmt.clib import Session
-from pygmt.exceptions import GMTInvalidInput
 from pygmt.helpers import (
     GMTTempFile,
     build_arg_string,
     fmt_docstring,
     kwargs_to_strings,
     use_alias,
+    validate_output_table_type,
 )
 
 __doctest_skip__ = ["grdvolume"]
@@ -39,8 +39,7 @@ def grdvolume(grid, output_type="pandas", outfile=None, **kwargs):
 
     Parameters
     ----------
-    grid : str or xarray.DataArray
-        The file name of the input grid or the grid loaded as a DataArray.
+    {grid}
     output_type : str
         Determine the format the output data will be returned in [Default is
         ``pandas``]:
@@ -50,7 +49,7 @@ def grdvolume(grid, output_type="pandas", outfile=None, **kwargs):
             - ``file`` - ASCII file (requires ``outfile``)
     outfile : str
         The file name for the output ASCII file.
-    contour : str or int or float or list
+    contour : str, float, or list
         *cval*\|\ *low/high/delta*\|\ **r**\ *low/high*\|\ **r**\ *cval*.
         Find area, volume and mean height (volume/area) inside and above the
         *cval* contour. Alternatively, search using all contours from *low* to
@@ -81,8 +80,8 @@ def grdvolume(grid, output_type="pandas", outfile=None, **kwargs):
     Example
     -------
     >>> import pygmt
-    >>> # Load a grid of @earth_relief_30m data, with an x-range of 10 to 30
-    >>> # degrees, and a y-range of 15 to 25 degrees
+    >>> # Load a grid of @earth_relief_30m data, with a longitude range of
+    >>> # 10° E to 30° E, and a latitude range of 15° N to 25° N
     >>> grid = pygmt.datasets.load_earth_relief(
     ...     resolution="30m", region=[10, 30, 15, 25]
     ... )
@@ -95,18 +94,13 @@ def grdvolume(grid, output_type="pandas", outfile=None, **kwargs):
     ... )
     >>> print(output_dataframe)
         0             1             2           3
-    0  200  2.318187e+12  8.533727e+14  368.120722
-    1  250  2.272471e+12  7.383936e+14  324.929840
-    2  300  2.162074e+12  6.273066e+14  290.141086
-    3  350  2.018302e+12  5.222640e+14  258.764032
-    4  400  1.857370e+12  4.252699e+14  228.963499
+    0  200  2.323600e+12  8.523815e+14  366.836554
+    1  250  2.275864e+12  7.371655e+14  323.905736
+    2  300  2.166707e+12  6.258570e+14  288.851699
+    3  350  2.019284e+12  5.207732e+14  257.899955
+    4  400  1.870441e+12  4.236191e+14  226.480847
     """
-    if output_type not in ["numpy", "pandas", "file"]:
-        raise GMTInvalidInput(
-            """Must specify format as either numpy, pandas, or file."""
-        )
-    if output_type == "file" and outfile is None:
-        raise GMTInvalidInput("""Must specify outfile for ASCII output.""")
+    output_type = validate_output_table_type(output_type, outfile=outfile)
 
     with GMTTempFile() as tmpfile:
         with Session() as lib:
