@@ -54,6 +54,6 @@ def logo(self, **kwargs):
     {panel}
     {transparency}
     """
-    kwargs = self._preprocess(**kwargs)  # pylint: disable=protected-access
+    kwargs = self._preprocess(**kwargs)
     with Session() as lib:
         lib.call_module(module="logo", args=build_arg_string(kwargs))
