@@ -40,11 +40,11 @@ def nearneighbor(data=None, x=None, y=None, z=None, **kwargs):
     r"""
     Grid table data using a "Nearest neighbor" algorithm.
 
-    **nearneighbor** reads arbitrarily located (*x*, *y*, *z*\ [, *w*]) triplets
-    [quadruplets] and uses a nearest neighbor algorithm to assign a weighted
-    average value to each node that has one or more data points within a search
-    radius centered on the node with adequate coverage across a subset of the
-    chosen sectors. The node value is computed as a weighted mean of the
+    **nearneighbor** reads arbitrarily located (*x*, *y*, *z*\ [, *w*])
+    triplets [quadruplets] and uses a nearest neighbor algorithm to assign a
+    weighted average value to each node that has one or more data points within
+    a search radius centered on the node with adequate coverage across a subset
+    of the chosen sectors. The node value is computed as a weighted mean of the
     nearest point from each sector inside the search radius. The weighting
     function and the averaging used is given by:
 
@@ -57,7 +57,7 @@ def nearneighbor(data=None, x=None, y=None, z=None, **kwargs):
     criteria and :math:`r_i` is the distance from the node to the *i*'th data
     point. If no data weights are supplied then :math:`w_i = 1`.
 
-    .. figure:: https://docs.generic-mapping-tools.org/dev/_images/GMT_nearneighbor.png # noqa: W505
+    .. figure:: https://docs.generic-mapping-tools.org/dev/_images/GMT_nearneighbor.png
        :width: 300 px
        :align: center
 
@@ -77,7 +77,7 @@ def nearneighbor(data=None, x=None, y=None, z=None, **kwargs):
 
     Parameters
     ----------
-    data : str or {table-like}
+    data : str, {table-like}
         Pass in (x, y, z) or (longitude, latitude, elevation) values by
         providing a file name to an ASCII data table, a 2-D
         {table-classes}.
@@ -91,11 +91,7 @@ def nearneighbor(data=None, x=None, y=None, z=None, **kwargs):
     search_radius : str
         Set the search radius that determines which data points are considered
         close to a node.
-
-    outgrid : str
-        Optional. The file name for the output netCDF file with extension .nc
-        to store the grid in.
-
+    {outgrid}
     empty : str
         Optional. Set the value assigned to empty nodes. Defaults to NaN.
 
@@ -139,7 +135,7 @@ def nearneighbor(data=None, x=None, y=None, z=None, **kwargs):
     >>> # Load a sample dataset of bathymetric x, y, and z values
     >>> data = pygmt.datasets.load_sample_data(name="bathymetry")
     >>> # Create a new grid with 5 arc-minutes spacing in the designated region
-    >>> # Set search_radius to only consider points within 10 arc-minutes of a node
+    >>> # Set search_radius to only take points within 10 arc-minutes of a node
     >>> output = pygmt.nearneighbor(
     ...     data=data,
     ...     spacing="5m",
@@ -149,7 +145,6 @@ def nearneighbor(data=None, x=None, y=None, z=None, **kwargs):
     """
     with GMTTempFile(suffix=".nc") as tmpfile:
         with Session() as lib:
-            # Choose how data will be passed into the module
             table_context = lib.virtualfile_from_data(
                 check_kind="vector", data=data, x=x, y=y, z=z, required_z=True
             )
