@@ -49,7 +49,9 @@ from pygmt.src.which import which
     w="wrap",
 )
 @kwargs_to_strings(R="sequence", c="sequence_comma", i="sequence_comma", p="sequence")
-def plot(self, data=None, x=None, y=None, size=None, direction=None, **kwargs):
+def plot(  # noqa: PLR0912
+    self, data=None, x=None, y=None, size=None, direction=None, **kwargs
+):
     r"""
     Plot lines, polygons, and symbols in 2-D.
 
@@ -77,7 +79,7 @@ def plot(self, data=None, x=None, y=None, size=None, direction=None, **kwargs):
 
     Parameters
     ----------
-    data : str or {table-like}
+    data : str, {table-like}
         Pass in either a file name to an ASCII data table, a 2-D
         {table-classes}.
         Use parameter ``incols`` to choose which columns are x, y, fill, and
@@ -120,41 +122,34 @@ def plot(self, data=None, x=None, y=None, size=None, direction=None, **kwargs):
         Draw error bars. Full documentation is at
         :gmt-docs:`plot.html#e`.
     connection : str
-        [**c**\|\ **n**\|\ **r**]\
-        [**a**\|\ **f**\|\ **s**\|\ **r**\|\ *refpoint*].
-        Alter the way points are connected (by specifying a *scheme*) and
-        data are grouped (by specifying a *method*). Append one of three
-        line connection schemes:
+        [**c**\|\ **n**\|\ **p**][**a**\|\ **r**\|\ **s**\|\ **t**\|\ *refpoint*].
+        Alter the way points are connected (by specifying a *scheme*) and data are
+        grouped (by specifying a *method*). Append one of three line connection schemes:
 
-        - **c** : Draw continuous line segments for each group [Default].
-        - **r** : Draw line segments from a reference point reset for each
-          group.
-        - **n** : Draw networks of line segments between all points in
-          each group.
+        - **c**: Draw continuous line segments for each group [Default].
+        - **n**: Draw networks of line segments between all points in each group.
+        - **p**: Draw line segments from a reference point reset for each group.
 
-        Optionally, append the one of four segmentation methods to define
-        the group:
+        Optionally, append the one of four segmentation methods to define the group:
 
-        - **a** : Ignore all segment headers, i.e., let all points belong
-          to a single group, and set group reference point to the very
-          first point of the first file.
-        - **f** : Consider all data in each file to be a single separate
-          group and reset the group reference point to the first point of
-          each group.
-        - **s** : Segment headers are honored so each segment is a group;
-          the group reference point is reset to the first point of each
-          incoming segment [Default].
-        - **r** : Same as **s**, but the group reference point is reset
-          after each record to the previous point (this method is only
-          available with the ``connection="r"`` scheme).
+        - **a**: Ignore all segment headers, i.e., let all points belong to a single
+          group, and set group the reference point to the very first point of the first
+          file.
+        - **r**: Segment headers are honored so each segment is a group; the group
+          reference point is reset after each record to the previous point (this method
+          is only available with the ``connection="p"`` scheme).
+        - **s**: Same as **r**, but the group reference point is reset to the first
+          point of each incoming segment [Default].
+        - **t**: Consider all data in each file to be a single separate group and reset
+          the group reference point to the first point of each group.
 
-        Instead of the codes **a**\|\ **f**\|\ **s**\|\ **r** you may append
-        the coordinates of a *refpoint* which will serve as a fixed external
-        reference point for all groups.
+        Instead of the codes **a**\|\ **r**\|\ **s**\|\ **t** you may append the
+        coordinates of a *refpoint* which will serve as a fixed external reference point
+        for all groups.
     {fill}
         *fill* can be a 1-D array, but it is only valid if using ``x``/``y``
         and ``cmap=True`` is also required.
-    intensity : float or bool or 1-D array
+    intensity : float, bool, or 1-D array
         Provide an *intensity* value (nominally in the -1 to +1 range) to
         modulate the fill color by simulating illumination. If using
         ``intensity=True``, we will instead read *intensity* from the first
@@ -210,8 +205,7 @@ def plot(self, data=None, x=None, y=None, size=None, direction=None, **kwargs):
         ``x``/``y``.
     {wrap}
     """
-    # pylint: disable=too-many-locals
-    kwargs = self._preprocess(**kwargs)  # pylint: disable=protected-access
+    kwargs = self._preprocess(**kwargs)
 
     kind = data_kind(data, x, y)
 
@@ -227,14 +221,14 @@ def plot(self, data=None, x=None, y=None, size=None, direction=None, **kwargs):
     elif kwargs.get("S") is None and kind == "file" and str(data).endswith(".gmt"):
         # checking that the data is a file path to set default style
         try:
-            with open(which(data), mode="r", encoding="utf8") as file:
+            with open(which(data), encoding="utf8") as file:
                 line = file.readline()
             if "@GMULTIPOINT" in line or "@GPOINT" in line:
                 # if the file is gmt style and geometry is set to Point
                 kwargs["S"] = "s0.2c"
         except FileNotFoundError:
             pass
-    if kwargs.get("G") is not None and is_nonstr_iter(kwargs["G"]):
+    if is_nonstr_iter(kwargs.get("G")):
         if kind != "vectors":
             raise GMTInvalidInput(
                 "Can't use arrays for fill if data is matrix or file."
@@ -249,7 +243,7 @@ def plot(self, data=None, x=None, y=None, size=None, direction=None, **kwargs):
         extra_arrays.append(size)
 
     for flag in ["I", "t"]:
-        if kwargs.get(flag) is not None and is_nonstr_iter(kwargs[flag]):
+        if is_nonstr_iter(kwargs.get(flag)):
             if kind != "vectors":
                 raise GMTInvalidInput(
                     f"Can't use arrays for {plot.aliases[flag]} if data is matrix or file."
@@ -258,7 +252,6 @@ def plot(self, data=None, x=None, y=None, size=None, direction=None, **kwargs):
             kwargs[flag] = ""
 
     with Session() as lib:
-        # Choose how data will be passed in to the module
         file_context = lib.virtualfile_from_data(
             check_kind="vector", data=data, x=x, y=y, extra_arrays=extra_arrays
         )
