@@ -64,7 +64,7 @@ def rose(self, data=None, length=None, azimuth=None, **kwargs):
 
     Parameters
     ----------
-    data : str or {table-like}
+    data : str, {table-like}
         Pass in either a file name to an ASCII data table, a 2-D
         {table-classes}.
         Use parameter ``incols`` to choose which columns are length and
@@ -199,10 +199,9 @@ def rose(self, data=None, length=None, azimuth=None, **kwargs):
     {wrap}
     """
 
-    kwargs = self._preprocess(**kwargs)  # pylint: disable=protected-access
+    kwargs = self._preprocess(**kwargs)
 
     with Session() as lib:
-        # Choose how data will be passed into the module
         file_context = lib.virtualfile_from_data(
             check_kind="vector", data=data, x=length, y=azimuth
         )
