@@ -41,13 +41,11 @@ def sph2grd(data, **kwargs):
 
     Parameters
     ----------
-    data : str or {table-like}
+    data : str, {table-like}
         Pass in data with L, M, C[L,M], S[L,M] values by
         providing a file name to an ASCII data table, a 2-D
         {table-classes}.
-    outgrid : str or None
-        The name of the output netCDF file with extension .nc to store the grid
-        in.
+    {outgrid}
     {spacing}
     {region}
     {verbose}
@@ -70,10 +68,8 @@ def sph2grd(data, **kwargs):
     -------
     >>> import pygmt
     >>> # Create a new grid from the remote file "EGM96_to_36.txt",
-    >>> # set the grid spacing to 1, and the region to "g"
-    >>> new_grid = pygmt.sph2grd(
-    ...     data="@EGM96_to_36.txt", spacing=1, region="g"
-    ... )
+    >>> # set the grid spacing to 1 arc-degree, and the region to global ("g")
+    >>> new_grid = pygmt.sph2grd(data="@EGM96_to_36.txt", spacing=1, region="g")
     """
     with GMTTempFile(suffix=".nc") as tmpfile:
         with Session() as lib:
