@@ -8,7 +8,6 @@ from pygmt.exceptions import GMTInvalidInput
 from pygmt.helpers import (
     build_arg_string,
     fmt_docstring,
-    is_nonstr_iter,
     kwargs_to_strings,
     use_alias,
 )
@@ -51,10 +50,10 @@ def subplot(self, nrows=1, ncols=1, **kwargs):
         Number of vertical rows of the subplot grid.
     ncols : int
         Number of horizontal columns of the subplot grid.
-    figsize : tuple
-        Specify the final figure dimensions as (*width*, *height*).
-    subsize : tuple
-        Specify the dimensions of each subplot directly as (*width*, *height*).
+    figsize : list
+        Specify the final figure dimensions as [*width*, *height*].
+    subsize : list
+        Specify the dimensions of each subplot directly as [*width*, *height*].
         Note that only one of ``figsize`` or ``subsize`` can be provided at
         once.
 
@@ -145,7 +144,7 @@ def subplot(self, nrows=1, ncols=1, **kwargs):
         [no heading]. Font is determined by setting :gmt-term:`FONT_HEADING`.
     {verbose}
     """
-    kwargs = self._preprocess(**kwargs)  # pylint: disable=protected-access
+    kwargs = self._preprocess(**kwargs)
 
     if nrows < 1 or ncols < 1:
         raise GMTInvalidInput("Please ensure that both 'nrows'>=1 and 'ncols'>=1.")
@@ -172,6 +171,7 @@ def subplot(self, nrows=1, ncols=1, **kwargs):
 @fmt_docstring
 @contextlib.contextmanager
 @use_alias(A="fixedlabel", C="clearance", V="verbose")
+@kwargs_to_strings(panel="sequence_comma")
 def set_panel(self, panel=None, **kwargs):
     r"""
     Set the current subplot panel to plot on.
@@ -220,9 +220,7 @@ def set_panel(self, panel=None, **kwargs):
 
     {verbose}
     """
-    kwargs = self._preprocess(**kwargs)  # pylint: disable=protected-access
-    # convert tuple or list to comma-separated str
-    panel = ",".join(map(str, panel)) if is_nonstr_iter(panel) else panel
+    kwargs = self._preprocess(**kwargs)
 
     with Session() as lib:
         arg_str = " ".join(["set", f"{panel}", build_arg_string(kwargs)])
