@@ -2,7 +2,6 @@
 triangulate - Delaunay triangulation or Voronoi partitioning and gridding of
 Cartesian data.
 """
-import warnings
 
 import pandas as pd
 from pygmt.clib import Session
@@ -13,14 +12,14 @@ from pygmt.helpers import (
     fmt_docstring,
     kwargs_to_strings,
     use_alias,
+    validate_output_table_type,
 )
 from pygmt.io import load_dataarray
 
 
-class triangulate:  # pylint: disable=invalid-name
+class triangulate:  # noqa: N801
     """
-    Delaunay triangulation or Voronoi partitioning and gridding of Cartesian
-    data.
+    Delaunay triangulation or Voronoi partitioning and gridding of Cartesian data.
 
     Triangulate reads in x,y[,z] data and performs Delaunay triangulation,
     i.e., it finds how the points should be connected to give the most
@@ -69,8 +68,7 @@ class triangulate:  # pylint: disable=invalid-name
         data=None, x=None, y=None, z=None, *, output_type, outfile=None, **kwargs
     ):
         """
-        Delaunay triangulation or Voronoi partitioning and gridding of
-        Cartesian data.
+        Delaunay triangulation or Voronoi partitioning and gridding of Cartesian data.
 
         Must provide ``outfile`` or ``outgrid``.
 
@@ -82,21 +80,20 @@ class triangulate:  # pylint: disable=invalid-name
         ----------
         x/y/z : np.ndarray
             Arrays of x and y coordinates and values z of the data points.
-        data : str or {table-like}
+        data : str, {table-like}
             Pass in (x, y, z) or (longitude, latitude, elevation) values by
             providing a file name to an ASCII data table, a 2-D
             {table-classes}.
         {projection}
         {region}
         {spacing}
-        outgrid : bool or str
-            The name of the output netCDF file with extension .nc to store the
-            grid in. The interpolation is performed in the original
-            coordinates, so if your triangles are close to the poles you are
-            better off projecting all data to a local coordinate system before
-            using ``triangulate`` (this is true of all gridding routines) or
-            instead select :gmt-docs:`sphtriangulate <sphtriangulate.html>`.
-        outfile : str or bool or None
+        {outgrid}
+            The interpolation is performed in the original coordinates, so if
+            your triangles are close to the poles you are better off projecting
+            all data to a local coordinate system before using ``triangulate``
+            (this is true of all gridding routines) or instead select
+            :gmt-docs:`sphtriangulate <sphtriangulate.html>`.
+        outfile : str, bool or None
             The name of the output ASCII file to store the results of the
             histogram equalization in.
         output_type: str
@@ -126,7 +123,6 @@ class triangulate:  # pylint: disable=invalid-name
               ``outgrid`` or ``outfile``)
         """
         with Session() as lib:
-            # Choose how data will be passed into the module
             table_context = lib.virtualfile_from_data(
                 check_kind="vector", data=data, x=x, y=y, z=z, required_z=False
             )
@@ -150,7 +146,7 @@ class triangulate:  # pylint: disable=invalid-name
 
     @staticmethod
     @fmt_docstring
-    def regular_grid(  # pylint: disable=too-many-arguments,too-many-locals
+    def regular_grid(  # noqa: PLR0913
         data=None,
         x=None,
         y=None,
@@ -198,20 +194,19 @@ class triangulate:  # pylint: disable=invalid-name
         ----------
         x/y/z : np.ndarray
             Arrays of x and y coordinates and values z of the data points.
-        data : str or {table-like}
+        data : str, {table-like}
             Pass in (x, y[, z]) or (longitude, latitude[, elevation]) values by
             providing a file name to an ASCII data table, a 2-D
             {table-classes}.
         {projection}
         {region}
         {spacing}
-        outgrid : str or None
-            The name of the output netCDF file with extension .nc to store the
-            grid in. The interpolation is performed in the original
-            coordinates, so if your triangles are close to the poles you are
-            better off projecting all data to a local coordinate system before
-            using ``triangulate`` (this is true of all gridding routines) or
-            instead select :gmt-docs:`sphtriangulate <sphtriangulate.html>`.
+        {outgrid}
+            The interpolation is performed in the original coordinates, so if
+            your triangles are close to the poles you are better off projecting
+            all data to a local coordinate system before using ``triangulate``
+            (this is true of all gridding routines) or instead select
+            :gmt-docs:`sphtriangulate <sphtriangulate.html>`.
         {verbose}
         {binary}
         {nodata}
@@ -276,7 +271,7 @@ class triangulate:  # pylint: disable=invalid-name
 
     @staticmethod
     @fmt_docstring
-    def delaunay_triples(  # pylint: disable=too-many-arguments,too-many-locals
+    def delaunay_triples(  # noqa: PLR0913
         data=None,
         x=None,
         y=None,
@@ -315,7 +310,7 @@ class triangulate:  # pylint: disable=invalid-name
         ----------
         x/y/z : np.ndarray
             Arrays of x and y coordinates and values z of the data points.
-        data : str or {table-like}
+        data : str, {table-like}
             Pass in (x, y, z) or (longitude, latitude, elevation) values by
             providing a file name to an ASCII data table, a 2-D
             {table-classes}.
@@ -358,20 +353,7 @@ class triangulate:  # pylint: disable=invalid-name
         ``triangulate`` is a Cartesian or small-geographic area operator and is
         unaware of periodic or polar boundary conditions.
         """
-        # Return a pandas.DataFrame if ``outfile`` is not set
-        if output_type not in ["numpy", "pandas", "file"]:
-            raise GMTInvalidInput(
-                "Must specify 'output_type' either as 'numpy', 'pandas' or 'file'."
-            )
-
-        if isinstance(outfile, str) and output_type != "file":
-            msg = (
-                f"Changing 'output_type' from '{output_type}' to 'file' "
-                "since 'outfile' parameter is set. Please use output_type='file' "
-                "to silence this warning."
-            )
-            warnings.warn(message=msg, category=RuntimeWarning, stacklevel=2)
-            output_type = "file"
+        output_type = validate_output_table_type(output_type, outfile)
 
         # Return a pandas.DataFrame if ``outfile`` is not set
         with GMTTempFile(suffix=".txt") as tmpfile:
